@@ -4,17 +4,9 @@ from .security.manager import SecurityManager
 from .views import IndexView
 from filters import TemplateFilters
 from flask import Blueprint
-from flask.ext.babel import Babel, gettext as _gettext, lazy_gettext
+from flask.ext.babel import gettext as _gettext, lazy_gettext
 from flask.ext.appbuilder.babel.manager import BabelManager
 from menu import Menu
-import os
-
-
-
-
-AUTH_OID = 0
-AUTH_DB = 1
-AUTH_LDAP = 2
 
 
 class BaseApp():
@@ -71,7 +63,6 @@ class BaseApp():
             param static_url_path:
                 optional, your override for the global static url path
         """
-        self.menu = menu or Menu()
         self.app = app
         self.db = db
         
@@ -81,6 +72,12 @@ class BaseApp():
         self.sm = SecurityManager(app, db.session)
         self.babelmanager = BabelManager(app)
         
+        if menu:
+            self.menu = menu
+            self._add_menu_permissions()
+        else:
+            self.menu = Menu()
+        
         self.app.before_request(self.sm.before_request)
         
         self._init_config_parameters()
@@ -91,6 +88,8 @@ class BaseApp():
         self._add_global_static()
         self._add_global_filters()        
     
+        
+        
     
     def _init_config_parameters(self):
         if 'APP_NAME' in self.app.config:
@@ -126,8 +125,19 @@ class BaseApp():
             baseview_class.datamodel.session = self.db.session
         return baseview_class()
     
+    def _add_permissions_menu(self, name):
+        try:
+            self.sm.add_permissions_menu(name)
+        except:
+            print "Add Permission on Menu Error: DB not created"
     
     
+    def _add_menu_permissions(self):
+        for category in self.menu.get_list():
+            self._add_permissions_menu(category.name)
+            for item in category.childs:
+                self._add_permissions_menu(item.name)
+    
     def add_view(self, baseview, name, href = "", icon = "", category = ""):
         
         print "Registering:", category,".", name
@@ -141,12 +151,8 @@ class BaseApp():
     def add_link(self, name, href, icon = "", category = "", baseview = None):
         self.menu.add_link(name = name, href = href, icon = icon, 
                         category = category, baseview = baseview)
-        try:
-            self.sm.add_permissions_menu(name)
-            self.sm.add_permissions_menu(category)            
-        except:
-            print "Add Permission on Menu Error: DB not created"
-    
+        self._add_permissions_menu(name)
+        self._add_permissions_menu(category)
 
     def add_separator(self, category):
         self.menu.add_separator(category)
