@@ -42,16 +42,16 @@ class SQLAModel(DataModel):
     
     def _get_base_query(self, query = None, filters = {}, order_column = '', order_direction = ''):
         for filter_key in filters:
-            try:
-                rel_model, rel_direction = self._get_related_model(filter_key)
-                item = (filters.get(filter_key))
+            if self.is_relation_col(filter_key):
+                item = filters.get(filter_key)
+                rel_direction = self._get_relation_direction(filter_key)
                 if rel_direction == 'MANYTOONE':
                     query = query.filter(getattr(self.obj,filter_key) == item)
                 elif rel_direction == 'MANYTOMANY':
                     query = query.filter(getattr(self.obj,filter_key).contains(item))
                 else:
                     pass
-            except:
+            else:
                 if self.is_string(filter_key) or self.is_text(filter_key):
                     query = query.filter(getattr(self.obj,filter_key).like(filters.get(filter_key) + '%'))
         if (order_column != ''):
@@ -184,19 +184,19 @@ class SQLAModel(DataModel):
     -----------------------------------------
     """
     def add(self, item):
-        #try:
+        try:
             self.session.add(item)
             self.session.commit()
             flash(unicode(self.add_row_message),'success')
             return True
-        #except IntegrityError as e:
-        #    flash(unicode(self.add_integrity_error_message),'warning')
-        #    self.session.rollback()
-        #    return False
-        #except:
-        #    flash(unicode(self.general_error_message + ' '  + str(sys.exc_info()[0])),'danger')
-        #    self.session.rollback()
-        #    return False
+        except IntegrityError as e:
+            flash(unicode(self.add_integrity_error_message),'warning')
+            self.session.rollback()
+            return False
+        except:
+            flash(unicode(self.general_error_message + ' '  + str(sys.exc_info()[0])),'danger')
+            self.session.rollback()
+            return False
 
     def edit(self, item):
         try:
@@ -275,9 +275,15 @@ class SQLAModel(DataModel):
                     return self.get_model_relation(i), i.direction.name
         return None
 
+    def _get_relation_direction(self, col_name):
+        for i in self.get_properties_iterator():
+            if self.is_relation(i):
+                if (i.key == col_name):
+                    return i.direction.name
+
     def get_related_obj(self, col_name, value):
         rel_model, rel_direction = self._get_related_model(col_name)
-        return rel_model.query.get(value)
+        return self.session.query(rel_model).get(value)
 
     def get_related_fks(self, related_views):
         return [view.datamodel.get_related_fk(self.obj) for view in related_views]
